@@ -9,14 +9,16 @@
 #' @section Map data frames:
 #' Alaska and Hawaii have been manually moved to a new location so that
 #' their new coordinates place them to the bottom-left corner of
-#' the map. These maps can be accessed by using the \code{\link{us_map}} function.
+#' the map. These maps can be accessed by using the [us_map] function.
 #'
 #' The function provides the ability to retrieve maps with either
 #' state borders or county borders using the \code{regions} parameter
 #' for convenience.
 #'
-#' States (or counties) can be included such that all other states (or counties)
-#' are excluded using the \code{include} parameter.
+#' States (or counties) can be included and excluded using the provided
+#' \code{include} and \code{exclude} parameters. These parameters can be used
+#' together with any combination of names, abbreviations, or FIPS code to
+#' create more complex maps.
 #'
 #' @section FIPS lookup tools:
 #' Several functions have been included to lookup the US state or county
@@ -27,8 +29,8 @@
 #' preparing data to be merged with the map data frame.
 #'
 #' @section Plot US map data:
-#' A convenience function \code{\link{plot_usmap}} has been included which
-#' takes similar parameters to \code{\link{us_map}} and returns a \pkg{ggplot2}
+#' A convenience function [plot_usmap] has been included which
+#' takes similar parameters to [us_map] and returns a [ggplot2::ggplot2]
 #' object. Since the output is a \code{ggplot} object, other layers can be
 #' added such as scales, themes, and labels. Including data in the function call
 #' will color the map according to the values in the data, creating a choropleth.
@@ -47,7 +49,7 @@
 #'     \url{https://en.wikipedia.org/wiki/FIPS_county_code}
 #'     \url{https://en.wikipedia.org/wiki/FIPS_state_code}
 #'   \item US Census Shapefiles \cr
-#'     \url{https://www.census.gov/geographies/mapping-files/time-series/geo/tiger-line-file.html}
+#'     \url{https://www.census.gov/geographies/mapping-files/time-series/geo/cartographic-boundary.html}
 #'   \item Map Features \cr
 #'     \url{https://en.wikipedia.org/wiki/Map_projection}
 #'     \url{https://en.wikipedia.org/wiki/Albers_projection}
@@ -57,7 +59,7 @@
 #' @references
 #' Rudis, Bob. "Moving The Earth (well, Alaska & Hawaii) With R."
 #' Blog post. Rud.is., 16 Nov. 2014. Web. 10 Aug. 2015.
-#' <\url{https://rud.is/b/2014/11/16/moving-the-earth-well-alaska-hawaii-with-r/}>.
+#' \url{https://rud.is/b/2014/11/16/moving-the-earth-well-alaska-hawaii-with-r/}.
 #'
 #' @docType package
 #' @name usmap
@@ -85,6 +87,8 @@ if (getRversion() >= "2.15.1")
 #'  \code{exclude} regions are then removed from the resulting map. Any excluded regions
 #'  not present in the included regions will be ignored.
 #'
+#' @seealso [usmapdata::us_map()] of which this function is a wrapper for.
+#'
 #' @return A data frame of US map coordinates divided by the desired \code{regions}.
 #'
 #' @examples
@@ -98,42 +102,11 @@ if (getRversion() >= "2.15.1")
 us_map <- function(regions = c("states", "state", "counties", "county"),
                    include = c(),
                    exclude = c()) {
-
-  regions_ <- match.arg(regions)
-
-  if (regions_ == "state") regions_ <- "states"
-  else if (regions_ == "county") regions_ <- "counties"
-
-  df <- utils::read.csv(system.file("extdata", paste0("us_", regions_, ".csv"), package = "usmap"),
-                        colClasses = col_classes(regions_),
-                        stringsAsFactors = FALSE)
-
-  if (length(include) > 0) {
-    df <- df[df$full %in% include |
-               df$abbr %in% include |
-               df$fips %in% include |
-               substr(df$fips, 1, 2) %in% include, ]
+  # check for usmapdata
+  if (!requireNamespace("usmapdata", quietly = TRUE)) {
+    stop("`usmapdata` must be installed to use `plot_usmap`.
+         Use: install.packages(\"usmapdata\") and try again.")
   }
 
-  if (length(exclude) > 0) {
-    df <- df[!(df$full %in% exclude |
-                 df$abbr %in% exclude |
-                 df$fips %in% exclude |
-                 substr(df$fips, 1, 2) %in% exclude), ]
-  }
-
-  df
-}
-
-#' Map data column classes
-#'
-#' @keywords internal
-col_classes <- function(regions) {
-  result <- c("numeric", "numeric", "integer", "logical", "integer", rep("character", 4))
-
-  if (regions %in% c("county", "counties")) {
-    result <- c(result, "character")    # add extra column for county name
-  }
-
-  result
+  usmapdata::us_map(regions = regions, include = include, exclude = exclude)
 }
